use MooseX::Declare;
use true;

#  PODNAME: $name
# ABSTRACT: 

class {{$name}} extends MooseX::App::Cmd {
    use MooseX::StrictConstructor;
    use MooseX::AlwaysCoerce;
    use MooseX::Types::Moose -all;

    
}

=begin wikidoc

=end wikidoc

=cut